@@ -1,5 +1,5 @@
 /*
- * $Id: gfarm_pfunc.c 9879 2015-08-27 03:21:02Z takuya-i $
+ * $Id: gfarm_pfunc.c 10000 2016-01-04 07:04:07Z tatebe $
  */
 
 #include <stdio.h>
@@ -188,7 +188,7 @@ retry:
 			"ERROR: cannot replicate: %s (%s:%d, %s:%d): %s\n",
 			url, src_host, src_port, dst_host, dst_port,
 			gfarm_error_string(e));
-		if (retry >= RETRY_MAX) {
+		if (retry >= RETRY_MAX || e == GFARM_ERR_DISK_QUOTA_EXCEEDED) {
 			result = PFUNC_RESULT_NG;
 			goto end;
 		}
@@ -704,9 +704,12 @@ pfunc_copy_to_gfarm_or_local(gfarm_pfunc_t *handle, FILE *to_parent,
 		if (handle->skip_existing && e == GFARM_ERR_ALREADY_EXISTS) {
 			result = PFUNC_RESULT_SKIP;
 		} else {
+			if (e == GFARM_ERR_DISK_QUOTA_EXCEEDED)
+				result = PFUNC_RESULT_NG_NOT_RETRY;
+			else
+				result = PFUNC_RESULT_NG;
 			fprintf(stderr, "ERROR: copy failed: open(%s): %s\n",
 			    tmp_url, gfarm_error_string(e));
-			result = PFUNC_RESULT_NG;
 		}
 		goto end;
 	}
@@ -820,6 +823,10 @@ pfunc_copy_main(gfarm_pfunc_t *handle, int pfunc_mode,
 			result = pfunc_copy_to_gfarm_or_local(handle, to_parent,
 			    src_url, src_host, src_port, src_size,
 			    dst_url, dst_host, dst_port, check_disk_avail);
+		if (result == PFUNC_RESULT_NG_NOT_RETRY) {
+			result = PFUNC_RESULT_NG;
+			break;
+		}
 		if (result != PFUNC_RESULT_NG || retry >= RETRY_MAX)
 			break;
 		retry++;
