@@ -346,6 +346,13 @@ gfarm_error_t gfm_client_lock_info_result(struct gfm_connection *,
 	gfarm_off_t *, gfarm_off_t *, gfarm_int32_t *, char **, gfarm_pid_t *);
 gfarm_error_t gfm_client_replica_open_status(struct gfm_connection *,
 	gfarm_ino_t, gfarm_uint64_t, gfarm_uint64_t *);
+gfarm_error_t gfm_client_replica_get_cksum(struct gfm_connection *,
+	gfarm_ino_t, gfarm_uint64_t,
+	char **, size_t, size_t *, char *, gfarm_int32_t *);
+gfarm_error_t gfm_client_fhset_cksum(struct gfm_connection *,
+	gfarm_ino_t, gfarm_uint64_t,
+	const char *, size_t, const char *, gfarm_int32_t flags);
+
 #if 1 /* should be 0, since gfmd has to be newer than gfsd */
 gfarm_error_t gfm_client_switch_back_channel(struct gfm_connection *);
 #endif
@@ -357,9 +364,19 @@ gfarm_error_t gfm_client_switch_gfmd_channel(struct gfm_connection *,
 /* gfs_pio from client */
 /*XXX*/
 
-/* misc operations from gfsd */
+/* miscellaneous */
+gfarm_error_t gfm_client_hostname_set_request(
+	struct gfm_connection *, const char *);
+gfarm_error_t gfm_client_hostname_set_result(struct gfm_connection *);
 gfarm_error_t gfm_client_hostname_set(struct gfm_connection *, const char *);
 
+gfarm_error_t gfm_client_config_get_request(struct gfm_connection *,
+	const char *, char);
+gfarm_error_t gfm_client_config_get_result(struct gfm_connection *,
+	char, void *);
+gfarm_error_t gfm_client_config_get(struct gfm_connection *,
+	const char *, char, void *);
+
 /* replica management from client */
 gfarm_error_t gfm_client_replica_list_by_name_request(struct gfm_connection *);
 gfarm_error_t gfm_client_replica_list_by_name_result(struct gfm_connection *,
