@@ -200,11 +200,13 @@ enum gfm_proto_command {
 	GFM_PROTO_PIO_MISC_RESERVE14,
 	GFM_PROTO_PIO_MISC_RESERVE15,
 
+	/* miscellaneous */
+
 	GFM_PROTO_HOSTNAME_SET,
 	GFM_PROTO_SCHEDULE_HOST_DOMAIN,
 	GFM_PROTO_STATFS,
-	GFM_PROTO_MISC_RESERVE3,
-	GFM_PROTO_MISC_RESERVE4,
+	GFM_PROTO_CONFIG_GET,			/* since gfarm-2.6.8 */
+	GFM_PROTO_CONFIG_SET,			/* reserved (not used yet) */
 	GFM_PROTO_MISC_RESERVE5,
 	GFM_PROTO_MISC_RESERVE6,
 	GFM_PROTO_MISC_RESERVE7,
@@ -251,8 +253,8 @@ enum gfm_proto_command {
 	GFM_PROTO_REPLICA_ADDING_CKSUM,		/* since gfarm-2.6.0 */
 	GFM_PROTO_REPLICA_ADDED_CKSUM,		/* since gfarm-2.6.0 */
 	GFM_PROTO_REPLICA_OPEN_STATUS,		/* since gfarm-2.6.6 */
-	GFM_PROTO_REPLICA_MNG_RESERVE13,
-	GFM_PROTO_REPLICA_MNG_RESERVE14,
+	GFM_PROTO_REPLICA_GET_CKSUM,		/* since gfarm-2.6.8 */
+	GFM_PROTO_FHSET_CKSUM,			/* since gfarm-2.6.8 */
 	GFM_PROTO_REPLICA_MNG_RESERVE15,
 
 	/* job management */
@@ -363,15 +365,20 @@ enum gfm_proto_command {
 #define GFM_PROTO_REPLICA_CHECK_CTRL_REDUCED_LOG_DISABLE	5
 
 /*
- * GFM_PROTO_CKSUM_GET result flags
+ * result flags of GFM_PROTO_CKSUM_GET and GFM_PROTO_REPLICA_GET_CKSUM.
  * see cksum request_flags of GFS_PROTO_REPLICATION_CKSUM_REQUEST,
  * GFS_PROTO_REPLICA_RECV_CKSUM and GFM_PROTO_REPLICA_ADDING_CKSUM as well.
+ *
+ * NOTE:
+ * GFM_PROTO_REPLICA_GET_CKSUM never returns GFM_PROTO_CKSUM_GET_EXPIRED
+ * but reports GFARM_ERR_NO_SUCH_OBJECT due to generation update of the inode.
  */
 #define	GFM_PROTO_CKSUM_GET_MAYBE_EXPIRED	0x00000001
 #define	GFM_PROTO_CKSUM_GET_EXPIRED		0x00000002
 
 /*
  * GFM_PROTO_CKSUM_SET request flags
+ * and maybe GFM_PROTO_FHSET_CKSUM too? (not really used at least for now)
  */
 #define	GFM_PROTO_CKSUM_SET_REPORT_ONLY		0x00000001 /* since 2.6.1 */
 
