@@ -1,5 +1,5 @@
 /*
- * $Id: gfmd.c 9872 2015-08-25 06:29:05Z takuya-i $
+ * $Id: gfmd.c 10028 2016-01-12 13:39:51Z tatebe $
  */
 
 #include <gfarm/gfarm_config.h>
@@ -435,6 +435,9 @@ protocol_switch(struct peer *peer, int from_client, int skip, int level,
 	case GFM_PROTO_STATFS:
 		e = gfm_server_statfs(peer, from_client, skip);
 		break;
+	case GFM_PROTO_CONFIG_GET:
+		e = gfm_server_config_get(peer, from_client, skip);
+		break;
 	case GFM_PROTO_REPLICA_LIST_BY_NAME:
 		e = gfm_server_replica_list_by_name(peer, from_client, skip);
 		break;
@@ -493,6 +496,12 @@ protocol_switch(struct peer *peer, int from_client, int skip, int level,
 	case GFM_PROTO_REPLICA_OPEN_STATUS:
 		e = gfm_server_replica_open_status(peer, from_client, skip);
 		break;
+	case GFM_PROTO_REPLICA_GET_CKSUM:
+		e = gfm_server_replica_get_cksum(peer, from_client, skip);
+		break;
+	case GFM_PROTO_FHSET_CKSUM:
+		e = gfm_server_fhset_cksum(peer, from_client, skip);
+		break;
 	case GFM_PROTO_PROCESS_ALLOC:
 		e = gfm_server_process_alloc(peer, from_client, skip);
 		break;
@@ -1617,6 +1626,9 @@ main(int argc, char **argv)
 
 	if (config_file == NULL)
 		config_file = GFMD_CONFIG;
+	gfarm_metadb_version_major = gfarm_version_major();
+	gfarm_metadb_version_minor = gfarm_version_minor();
+	gfarm_metadb_version_teeny = gfarm_version_teeny();
 	e = gfarm_server_initialize(config_file, &argc, &argv);
 	if (e != GFARM_ERR_NO_ERROR) {
 		gflog_debug(GFARM_MSG_1001486,
