@@ -905,6 +905,14 @@ process_close_file(struct process *process, struct peer *peer, int fd,
 
 		/* i.e. REOPENed file, and I am a gfsd. */
 		if ((accmode_to_op(fo->flag) & GFS_W_OK) != 0) {
+			gflog_warning(GFARM_MSG_1004354,
+			    "gfsd on %s@%s exited without closing write-opened"
+			    " file (pid:%lld fd:%d). inode %llu:%llu"
+			    " might be modified, run gfspooldigest",
+			    peer_get_username(peer), peer_get_hostname(peer),
+			    (long long)process->pid, (int)fd,
+			    (long long)inode_get_number(fo->inode),
+			    (long long)inode_get_gen(fo->inode));
 			inode_del_ref_spool_writers(fo->inode);
 			inode_check_pending_replication(fo);
 		}
@@ -1414,8 +1422,14 @@ process_replica_added(struct process *process,
 		    GFS_PROTO_REPLICATION_CKSUM_REQFLAG_INTERNAL_SUM_AVAIL
 		    ) == 0 && cksum_type != NULL && *cksum_type != '\0' &&
 		    cksum_len > 0) {
+			int cksum_is_set;
+
+			/*
+			 * calling inode_cksum_set() without checking
+			 * `cs == NULL' is OK, since r8972.
+			 */
 			e = inode_cksum_set(fo->inode, cksum_type, cksum_len,
-			    cksum, cksum_result_flags, 0);
+			    cksum, cksum_result_flags, 0, &cksum_is_set);
 			if (e != GFARM_ERR_NO_ERROR)
 				gflog_notice(GFARM_MSG_1004221,
 				    "checksum error during replication of "
@@ -1424,6 +1438,14 @@ process_replica_added(struct process *process,
 				    (long long)fo->u.f.replica_source->gen,
 				    host_name(spool_host),
 				    gfarm_error_string(e));
+			else if (cksum_is_set)
+				gflog_notice(GFARM_MSG_1004355,
+				    "inode %lld:%lld: checksum set to "
+				    "<%s>:<%.*s> by replication to %s",
+				    (long long)inode_get_number(fo->inode),
+				    (long long)fo->u.f.replica_source->gen,
+				    cksum_type, (int)cksum_len, cksum,
+				    host_name(spool_host));
 		}
 		if (e == GFARM_ERR_NO_ERROR) {
 			e = inode_add_replica(fo->inode, spool_host, 1);
